@@ -1,8 +1,19 @@
 // Copyright 2018-2021 the Deno authors. All rights reserved. MIT license.
 
+/// <reference path="../../core/internal.d.ts" />
+
 ((window) => {
   const core = window.Deno.core;
   const webidl = window.__bootstrap.webidl;
+  const {
+    Symbol,
+    SymbolFor,
+    ObjectDefineProperty,
+    ObjectFromEntries,
+    ObjectEntries,
+    ReflectGet,
+    Proxy,
+  } = window.__bootstrap.primordials;
 
   const _persistent = Symbol("[[persistent]]");
 
@@ -96,7 +107,7 @@
       },
       defineProperty(target, key, descriptor) {
         if (typeof key == "symbol") {
-          Object.defineProperty(target, key, descriptor);
+          ObjectDefineProperty(target, key, descriptor);
         } else {
           target.setItem(key, descriptor.value);
         }
@@ -105,14 +116,14 @@
       get(target, key) {
         if (typeof key == "symbol") return target[key];
         if (key in target) {
-          return Reflect.get(...arguments);
+          return ReflectGet(...arguments);
         } else {
           return target.getItem(key) ?? undefined;
         }
       },
       set(target, key, value) {
         if (typeof key == "symbol") {
-          Object.defineProperty(target, key, {
+          ObjectDefineProperty(target, key, {
             value,
             configurable: true,
           });
@@ -147,11 +158,11 @@
       },
     });
 
-    proxy[Symbol.for("Deno.customInspect")] = function (inspect) {
+    proxy[SymbolFor("Deno.customInspect")] = function (inspect) {
       return `${this.constructor.name} ${
         inspect({
           length: this.length,
-          ...Object.fromEntries(Object.entries(proxy)),
+          ...ObjectFromEntries(ObjectEntries(proxy)),
         })
       }`;
     };
